@@ -38,7 +38,7 @@ known_sources = [
 
     # level 4
 
-    'ssreflect', 'coq-corn',
+    'ssreflect', 'coq-corn', 'metacoq',
 
     # level 5
 
@@ -105,6 +105,7 @@ known_tests = {
     'mathcomp-multinomials': (None, 'mathcomp.multinomials', 'mpoly'),
     'mathcomp-real-closed': (None, 'mathcomp.real_closed', 'complex'),
     'mathcomp-zify': (None, 'mathcomp', 'zify'),
+    'metacoq': (None, 'MetaCoq.Template', 'All'),
     'ott': (None, 'Ott', 'ott_list'),
     'paramcoq': (None, 'Param', 'Param'),
     'ssreflect': (None, 'mathcomp', 'ssreflect'),
